'use client';

import { Empty } from 'antd';
import Link from 'next/link';
import { memo } from 'react';
import { useTranslation } from 'react-i18next';
import urlJoin from 'url-join';
import { useRouter } from 'next/navigation';
import { DiscoverModelItem } from '@/types/discover';
import { Grid } from '@lobehub/ui';
import SearchResultCount from '../../../components/SearchResultCount';
import Title from '../../../components/Title';
import VirtuosoGridList from '../../../components/VirtuosoGridList';
import Card from './Card';
import request from '@/app/api/request';
import { useUserStore } from '@/store/user';
export interface ListProps {
  category?: string;
  items?: DiscoverModelItem[];
  mobile?: boolean;
  searchKeywords?: string;
}

const List = memo<ListProps>(async ({ category, searchKeywords, items = [] }) => {
  const { t } = useTranslation('discover');
  const router = useRouter()
  const getUserId = (s: UserStore) => s.user?.id
  const userId = getUserId(useUserStore.getState())
  console.log(userId,'models---3837373266262266')
	console.log('models---99999999',items)
  if(category == "collect") {
    const res = await request({
        url: "/flxai/api/robot/appaimodel/getAllAiModel",
        method: "get",
        params: {
          userid: userId
        }
    })
    items = res.data;
    items = items.map((item,index)=> {
        item.classify = 'collect';
        return item
    })
  } else {
    const res = await request({
        url: "/flxai/api/robot/appaimodel/getAllAiModel",
        method: "get",
        params: {
          userid: userId
        }
    })
    const array2Object = {};
    res?.data?.forEach(item => {
      array2Object[item.identifier] = item;
    });
    items = items.map((item,index)=> {
        const matchingItem = array2Object[item.identifier];
        if (matchingItem) {
          console.log('3838383838',matchingItem);
          matchingItem.status = '1';
          return matchingItem
        } else {
          item.status = '0';
          return item
        }
    })
  }
  const handleClickCard = (item) => {
    console.log(item)
    router.push(urlJoin('/discover/model/', item.identifier))
  }
  if (searchKeywords) {
    if (!items || items?.length === 0) return <Empty image={Empty.PRESENTED_IMAGE_SIMPLE} />;
    return (
      <>
        <SearchResultCount count={items.length} keyword={searchKeywords} />
        <VirtuosoGridList
          data={items}
          initialItemCount={24}
          itemContent={(_, item) => (
            // <Link href={urlJoin('/discover/model/', item.identifier)} key={item.identifier}>
              <Card onClick={() => handleClickCard(item)} showCategory {...item} />
            // </Link>
          )}
          style={{
            minHeight: '75vh',
          }}
        />
      </>
    );
  }

  return (
    <>
      {category == "collect"?(
        <>
          <Title tag={items.length}>收藏列表</Title>
          <Grid maxItemWidth={280} rows={4}>
            {items.map((item) => (
              // <Link href={urlJoin('/discover/assistant/', item.identifier)} key={item.identifier}>
                <Card onClick={() => handleClickCard(item)} showCategory={!category} {...item} />
              // </Link>
            ))}
          </Grid>
        </>
      ):(
        <>
          <Title tag={items.length}>{t('models.list')}</Title>
          <VirtuosoGridList
            data={items}
            initialItemCount={24}
            itemContent={(_, item) => (
              // <Link href={urlJoin('/discover/model/', item.identifier)} key={item.identifier}>
                <Card onClick={() => handleClickCard(item)} showCategory={!category} {...item} />
              // </Link>
            )}
            style={{
              minHeight: '75vh',
            }}
          />
        </>
      )}
    </>
  );
});

export default List;
