package com.pjilisense.flxai.controller;

import com.pjilisense.flxai.base.constant.Constant;
import com.pjilisense.flxai.page.PageData;
import com.pjilisense.flxai.utils.Result;
import com.pjilisense.flxai.dto.AppToolsSetDTO;
import com.pjilisense.flxai.service.AppToolsSetService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * AI应用工具集
 *
 * @author liushujing liushujing@philisense.com
 * @since 1.0.0 2024-12-12
 */
@RestController
@RequestMapping(Constant.BASE_PATH+"apptoolsset")
@Api(tags="AI应用工具集")
public class AppToolsSetController {

    private static Logger logger = LoggerFactory.getLogger(AppToolsSetController.class);

    @Autowired
    private AppToolsSetService appToolsSetService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String", dataTypeClass =String.class) ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String", dataTypeClass =String.class)
    })
    public Result<PageData<AppToolsSetDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<AppToolsSetDTO> page = appToolsSetService.page(params);

        return new Result<PageData<AppToolsSetDTO>>().ok(page);
    }

    @GetMapping("getAllAiTools")
    @ApiOperation("获取所有AI应用集")
    public Result<Map<String,Object>> getAllAiTools(){
        Map<String,Object> allTools = appToolsSetService.getAllAiTools();
        return new Result<Map<String,Object>>().ok(allTools);
    }
    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<AppToolsSetDTO> get(@PathVariable("id") String id){
        AppToolsSetDTO data = appToolsSetService.get(id);

        return new Result<AppToolsSetDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    public Result save(@RequestBody AppToolsSetDTO dto){
        //效验数据
        //ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        appToolsSetService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    public Result update(@RequestBody AppToolsSetDTO dto){
        //效验数据
        //ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        appToolsSetService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    public Result delete(@RequestBody String[] ids){
        //效验数据
//        AssertUtils.isArrayEmpty(ids, "id");

        appToolsSetService.delete(ids);

        return new Result();
    }

//    @GetMapping("export")
//    @ApiOperation("导出")
//    @LogOperation("导出")
//    public void export(@ApiIgnore @RequestParam Map<String, Object> params, HttpServletResponse response) throws Exception {
//        List<AppToolsSetDTO> list = appToolsSetService.list(params);
//
//        ExcelUtils.exportExcelToTarget(response, null, "AI应用工具集", list, AppToolsSetExcel.class);
//    }

}