package com.pjilisense.flxai.controller;

import com.pjilisense.flxai.base.constant.Constant;
import com.pjilisense.flxai.page.PageData;
import com.pjilisense.flxai.utils.Result;
import com.pjilisense.flxai.dto.AppToolsTypeDTO;
import com.pjilisense.flxai.service.AppToolsTypeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * AI应用工具集分类表
 *
 * @author liushujing liushujing@philisense.com
 * @since 1.0.0 2024-12-12
 */
@RestController
@RequestMapping(Constant.BASE_PATH+"apptoolstype")
@Api(tags="AI应用工具集分类表")
public class AppToolsTypeController {

    private static Logger logger = LoggerFactory.getLogger(AppToolsTypeController.class);

    @Autowired
    private AppToolsTypeService appToolsTypeService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="Integer", dataTypeClass =Integer.class) ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String", dataTypeClass =String.class) ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String", dataTypeClass =String.class)
    })
    public Result<PageData<AppToolsTypeDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<AppToolsTypeDTO> page = appToolsTypeService.page(params);

        return new Result<PageData<AppToolsTypeDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<AppToolsTypeDTO> get(@PathVariable("id") Long id){
        AppToolsTypeDTO data = appToolsTypeService.get(id);

        return new Result<AppToolsTypeDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    public Result save(@RequestBody AppToolsTypeDTO dto){
        //效验数据
        //ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        appToolsTypeService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    public Result update(@RequestBody AppToolsTypeDTO dto){
        //效验数据
        //ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        appToolsTypeService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    public Result delete(@RequestBody Long[] ids){
        //效验数据
        //AssertUtils.isArrayEmpty(ids, "id");

        appToolsTypeService.delete(ids);

        return new Result();
    }

//    @GetMapping("export")
//    @ApiOperation("导出")
//    public void export(@ApiIgnore @RequestParam Map<String, Object> params, HttpServletResponse response) throws Exception {
//        List<AppToolsTypeDTO> list = appToolsTypeService.list(params);
//
//        ExcelUtils.exportExcelToTarget(response, null, "AI应用工具集分类表", list, AppToolsTypeExcel.class);
//    }

}